import { ILayer, ILayerPlugin, IPass, IPostProcessingPass, IRendererService } from '@antv/l7-core';
import 'reflect-metadata';
/**
 * 'blurH' -> ['blurH', {}]
 */
export declare function normalizePasses(passes: Array<string | [string, {
    [key: string]: unknown;
}]>): [string, {
    [key: string]: unknown;
}][];
/**
 * 自定义渲染管线：
 * ClearPass -> PixelPickingPass(可选) -> RenderPass/TAAPass -> PostProcessing -> CopyPass
 * 根据 Layer 配置的 passes 创建 PostProcessing
 * @example
 * new PolygonLayer({
 *   enableMultiPassRenderer: true,
 *   passes: [
 *     'blurH',
 *     ['blurV', { radius: 10 }],
 *   ],
 * })
 */
export default class MultiPassRendererPlugin implements ILayerPlugin {
    private readonly configService;
    private enabled;
    apply(layer: ILayer, { rendererService, postProcessingPassFactory, normalPassFactory, }: {
        rendererService: IRendererService;
        postProcessingPassFactory: (name: string) => IPostProcessingPass<unknown>;
        normalPassFactory: (name: string) => IPass<unknown>;
    }): void;
    /**
     * 默认添加 ClearPass、RenderPass
     * 以及 PostProcessing 中的最后一个 CopyPass
     */
    private createMultiPassRenderer;
}
